@@ -3,15 +3,17 @@ Base class for numerical differentiation methods
 """
 import abc
 
+from sklearn.base import BaseEstimator
+
 from pysindy.utils.base import validate_input
 
 
-class BaseDifferentiation:
+class BaseDifferentiation(BaseEstimator):
     """
     Base class for differentiation methods.
 
     Simply forces differentiation methods to implement a
-    _differentiate function.
+    ``_differentiate`` function.
     """
 
     def __init__(self):
