@@ -3,3 +3,11 @@ from .feature_library import ConcatLibrary
 from .fourier_library import FourierLibrary
 from .identity_library import IdentityLibrary
 from .polynomial_library import PolynomialLibrary
+
+__all__ = [
+    "ConcatLibrary",
+    "CustomLibrary",
+    "FourierLibrary",
+    "IdentityLibrary",
+    "PolynomialLibrary",
+]
